Package: dados
Title: Translate Datasets to Portuguese
Version: 0.1.1
Authors@R: c(
    person(given = "Riva",
           family = "Quiroga",
           role = c("aut", "cre"),
           email = "riva.quiroga@uc.cl",
           comment = c(ORCID = "0000-0002-1147-4135")),
    person(given = "Beatriz",
           family = "Milz",
           role = c("aut"),
           email = "milz.bea@gmail.com",
           comment = c(ORCID = "0000-0002-3064-4486")),
    person(given = "Sara",
           family = "Mortara",
           role = c("aut"),
           email = "saramortara@gmail.com",
           comment = c(ORCID = "0000-0001-6221-7537")),
    person(given = "Andrea",
           family = "Sánchez-Tapia",
           role = c("aut"),
           email = "andreasancheztapia@gmail.com",
           comment = c(ORCID = "0000-0002-3521-4338")),
    person(given = "Alejandra Andrea",
           family = "Tapia Silva",
           role = c("aut"),
           email = "alejandraandreatapiasilva@gmail.com",
           comment = c(ORCID = "0000-0003-0762-7618")),
    person(given = "Beatriz",
           family = "Maurer Costa",
           role = c("aut"),
           email = "beatrizmcosta@me.com",
           ),
   person(given = "Jean",
           family = "Prado",
           role = c("aut"),
           email = "jeangrprado@gmail.com",
           comment = c(ORCID = "0000-0002-7928-774X")),
    person(given = "Renata",
           family = "Hirota",
           role = c("aut"),
           email = "re.hirota@gmail.com",
           comment = c(ORCID = "0000-0002-3589-3246")),
    person(given = "William",
           family = "Amorim",
           role = c("aut"),
           email = "wamorim@curso-r.com",
           comment = c(ORCID = "0000-0003-0543-3473")),
   person(given = "Emmanuelle",
          family = "Rodrigues Nunes",
          role = c("aut"),
          email = "emmanuellernunes@gmail.com",
          comment = c(ORCID = "0000-0001-5994-352X")
          ),
    person(given = "Eric",
          family = "Scopinho",
          role = "aut",
          email = "eric.scopinho@gmail.com")
        )
Description: Este pacote traduz os seguintes 
    conjuntos de dados: 'airlines', 'airports', 'ames_raw', 'AwardsManagers',
    'babynames', 'Batting', 'diamonds', 'faithful', 'fueleconomy',
    'Fielding', 'flights', 'gapminder', 'gss_cat', 'iris', 'Managers',
    'mpg', 'mtcars', 'atmos', 'penguins', 'People, 'Pitching', 'pixarfilms','planes',
    'presidential', 'table1', 'table2', 'table3', 'table4a', 'table4b',
    'table5', 'vehicles', 'weather', 'who'.  English: It provides a
    Portuguese translated version of the datasets listed above.
License: GPL-3
Encoding: UTF-8
Language: pt
LazyData: true
RoxygenNote: 7.2.3
URL: https://github.com/cienciadedatos/dados
BugReports: https://github.com/cienciadedatos/dados/issues
Depends: R (>= 3.5.0)
Imports: AmesHousing, babynames, dplyr, forcats, fueleconomy,
        gapminder, ggplot2, Lahman, palmerpenguins, nasaweather,
        nycflights13, rlang, tibble, tidyr, yaml, pixarfilms
Suggests: covr, testthat (>= 3.0.0)
NeedsCompilation: no
Packaged: 2026-05-15 15:47:25 UTC; ciruela
Author: Riva Quiroga [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1147-4135>),
  Beatriz Milz [aut] (ORCID: <https://orcid.org/0000-0002-3064-4486>),
  Sara Mortara [aut] (ORCID: <https://orcid.org/0000-0001-6221-7537>),
  Andrea Sánchez-Tapia [aut] (ORCID:
    <https://orcid.org/0000-0002-3521-4338>),
  Alejandra Andrea Tapia Silva [aut] (ORCID:
    <https://orcid.org/0000-0003-0762-7618>),
  Beatriz Maurer Costa [aut],
  Jean Prado [aut] (ORCID: <https://orcid.org/0000-0002-7928-774X>),
  Renata Hirota [aut] (ORCID: <https://orcid.org/0000-0002-3589-3246>),
  William Amorim [aut] (ORCID: <https://orcid.org/0000-0003-0543-3473>),
  Emmanuelle Rodrigues Nunes [aut] (ORCID:
    <https://orcid.org/0000-0001-5994-352X>),
  Eric Scopinho [aut]
Maintainer: Riva Quiroga <riva.quiroga@uc.cl>
Repository: CRAN
Date/Publication: 2026-05-15 20:30:19 UTC
Built: R 4.6.0; ; 2026-05-15 23:07:41 UTC; unix
