#' Vetores de caracteres do pacote stringr
#'
#' Amostra de vetores de caracteres para praticar a manipulação de strings
#'
#' frases - é uma lista de frases escritas em português
#'
#' frutas - é uma seleção e adaptação ao português dos dados de prática contidos em stringr::fruit.
#'
#' palavras - é uma lista de palavras frequentes usadas em português brasileiro
#' @format Um vetor
#' @name dados-stringr
#' @examples
#'
#' length(frases)
#' frases[1:5]
#'
#' length(frutas)
#' frutas[1:5]
#'
#' #' length(palavras)
#' palavras[1:5]
NULL

#' @rdname dados-stringr
"frases"

#' @rdname dados-stringr
"frutas"

#' @rdname dados-stringr
"palavras"
