#' @keywords internal
"_PACKAGE"

#' @importFrom yaml read_yaml
#' @importFrom dplyr as_tibble group_by
#' @importFrom tibble as_tibble
#' @importFrom stats setNames
#' @import rlang
NULL

# Suppress R CMD check note
# (e.g. https://github.com/tidyverse/tidyverse/blob/master/R/tidyverse.R#L4)
#' @importFrom forcats fct_c
#' @importFrom tidyr pivot_wider
#' @importFrom ggplot2 ggplot
#' @importFrom Lahman playerInfo
#' @import babynames
#' @import fueleconomy
#' @import gapminder
#' @import nasaweather
#' @import nycflights13
#' @import palmerpenguins
#' @import pixarfilms
#' @import AmesHousing
NULL
