delayedAssign('companhias_aereas',
        eval(parse(file.path(system.file('scripts','companhias_aereas.txt', package = 'datos')))))
delayedAssign('aeroportos',
        eval(parse(file.path(system.file('scripts','aeroportos.txt', package = 'datos')))))
delayedAssign('casas',
        eval(parse(file.path(system.file('scripts','casas.txt', package = 'datos')))))
delayedAssign('dados_atmosfera',
        eval(parse(file.path(system.file('scripts','dados_atmosfera.txt', package = 'datos')))))
delayedAssign('premios_gerentes',
        eval(parse(file.path(system.file('scripts','premios_gerentes.txt', package = 'datos')))))
delayedAssign('bebes',
        eval(parse(file.path(system.file('scripts','bebes.txt', package = 'datos')))))
delayedAssign('rebatedores',
        eval(parse(file.path(system.file('scripts','rebatedores.txt', package = 'datos')))))
delayedAssign('top100musicas',
        eval(parse(file.path(system.file('scripts','top100musicas.txt', package = 'datos')))))
delayedAssign('cms_paciente_experiencia',
        eval(parse(file.path(system.file('scripts','cms_paciente_experiencia.txt', package = 'datos')))))
delayedAssign('comuns',
        eval(parse(file.path(system.file('scripts','comuns.txt', package = 'datos')))))
delayedAssign('diamante',
        eval(parse(file.path(system.file('scripts','diamante.txt', package = 'datos')))))
delayedAssign('velho_fiel',
        eval(parse(file.path(system.file('scripts','velho_fiel.txt', package = 'datos')))))
delayedAssign('jardineiros',
        eval(parse(file.path(system.file('scripts','jardineiros.txt', package = 'datos')))))
delayedAssign('voos',
        eval(parse(file.path(system.file('scripts','voos.txt', package = 'datos')))))
delayedAssign('dados_gapminder',
        eval(parse(file.path(system.file('scripts','dados_gapminder.txt', package = 'datos')))))
delayedAssign('questionario',
        eval(parse(file.path(system.file('scripts','questionario.txt', package = 'datos')))))
delayedAssign('nucleo_familiar',
        eval(parse(file.path(system.file('scripts','nucleo_familiar.txt', package = 'datos')))))
delayedAssign('dados_iris',
        eval(parse(file.path(system.file('scripts','dados_iris.txt', package = 'datos')))))
delayedAssign('gerentes',
        eval(parse(file.path(system.file('scripts','gerentes.txt', package = 'datos')))))
delayedAssign('milhas',
        eval(parse(file.path(system.file('scripts','milhas.txt', package = 'datos')))))
delayedAssign('mtcarros',
        eval(parse(file.path(system.file('scripts','mtcarros.txt', package = 'datos')))))
delayedAssign('pinguins',
        eval(parse(file.path(system.file('scripts','pinguins.txt', package = 'datos')))))
delayedAssign('pessoas',
        eval(parse(file.path(system.file('scripts','pessoas.txt', package = 'datos')))))
delayedAssign('arremessadores',
        eval(parse(file.path(system.file('scripts','arremessadores.txt', package = 'datos')))))
delayedAssign('pixar_oscars',
        eval(parse(file.path(system.file('scripts','pixar_oscars.txt', package = 'datos')))))
delayedAssign('pixar_bilheteria',
        eval(parse(file.path(system.file('scripts','pixar_bilheteria.txt', package = 'datos')))))
delayedAssign('pixar_filmes',
        eval(parse(file.path(system.file('scripts','pixar_filmes.txt', package = 'datos')))))
delayedAssign('pixar_generos',
        eval(parse(file.path(system.file('scripts','pixar_generos.txt', package = 'datos')))))
delayedAssign('pixar_equipe',
        eval(parse(file.path(system.file('scripts','pixar_equipe.txt', package = 'datos')))))
delayedAssign('pixar_avalicao_publico',
        eval(parse(file.path(system.file('scripts','pixar_avalicao_publico.txt', package = 'datos')))))
delayedAssign('avioes',
        eval(parse(file.path(system.file('scripts','avioes.txt', package = 'datos')))))
delayedAssign('presidentes_eua',
        eval(parse(file.path(system.file('scripts','presidentes_eua.txt', package = 'datos')))))
delayedAssign('salarios',
        eval(parse(file.path(system.file('scripts','salarios.txt', package = 'datos')))))
delayedAssign('dados_starwars',
        eval(parse(file.path(system.file('scripts','dados_starwars.txt', package = 'datos')))))
delayedAssign('tabela1',
        eval(parse(file.path(system.file('scripts','tabela1.txt', package = 'datos')))))
delayedAssign('tabela2',
        eval(parse(file.path(system.file('scripts','tabela2.txt', package = 'datos')))))
delayedAssign('tabela3',
        eval(parse(file.path(system.file('scripts','tabela3.txt', package = 'datos')))))
delayedAssign('tabela4a',
        eval(parse(file.path(system.file('scripts','tabela4a.txt', package = 'datos')))))
delayedAssign('tabela4b',
        eval(parse(file.path(system.file('scripts','tabela4b.txt', package = 'datos')))))
delayedAssign('tabela5',
        eval(parse(file.path(system.file('scripts','tabela5.txt', package = 'datos')))))
delayedAssign('veiculos',
        eval(parse(file.path(system.file('scripts','veiculos.txt', package = 'datos')))))
delayedAssign('clima',
        eval(parse(file.path(system.file('scripts','clima.txt', package = 'datos')))))
delayedAssign('dados_oms',
        eval(parse(file.path(system.file('scripts','dados_oms.txt', package = 'datos')))))
delayedAssign('dados_oms2',
        eval(parse(file.path(system.file('scripts','dados_oms2.txt', package = 'datos')))))
