\docType{data}
\name{pixar_oscars}
\alias{pixar_oscars}
\title{Filmes da Pixar com indicações ao Oscar}
\format{Um tibble com 72 linhas e 3 colunas
\describe{
\item{filme}{Título do filme}
\item{tipo_premio_indicado}{Tipo de prêmio}
\item{resultado}{Resultado da indicação}
}}
\usage{pixar_oscars}
\description{Filmes da Pixar que foram indicados ao Oscar, a categoria em que concorreram e o resultado da indicação}
\keyword{datasets}
