\docType{data}
\name{tabela4b}
\alias{tabela4b}
\title{Registros de tuberculose da Organização Mundial da Saúde (variante 4a)}
\format{Um tibble com 3 linhas e 3 colunas
\describe{
\item{pais}{Nome do país}
\item{1999}{População no ano 1999}
\item{2000}{População no ano 2000}
}}
\description{Contém observações de casos registrados no Afeganistão, Brasil e China nos anos de 1999 e 2000}
\keyword{datasets}
